@@ -66,7 +66,7 @@ def fetch_yaml_context(context_location: str, schema_filename: str) -> Dict[str,
             yaml_resume = yaml.load(file, Loader=yaml.FullLoader)
         return yaml_resume
     else:
-        raise ValueError(msg.format(context_location=context_location))
+        raise ValueError(msg)
 
 
 def render_and_save(
@@ -176,7 +176,7 @@ def generate_resume(
         logging.error(
             f"The context in '{context_location}' does not contain a valid resume. Please review the spec in {schema_location}"
         )
-        exit(1)
+        return -1
     jinja_env = Environment()
     jinja_env.filters["with_badge"] = with_badge
     jinja_env.filters["without_badge"] = without_badge
